# basky

A lightweight, robust basket app for your Django project.

Based on [django-ccbasket][0] but has been updated to work with Django 1.5.

**Tests and documentation are being actively developed**

[0]: https://github.com/designcc/django-ccbasket
